@@ -31,6 +31,11 @@ MSO_INFO = {
         'username_field': 'user',
         'password_field': 'passwd',
     },
+    'TWC': {
+        'name': 'Time Warner Cable | Spectrum',
+        'username_field': 'Ecom_User_ID',
+        'password_field': 'Ecom_Password',
+    },
     'thr030': {
         'name': '3 Rivers Communications'
     },
@@ -1376,19 +1381,23 @@ class AdobePassIE(InfoExtractor):
                     provider_redirect_page, urlh = provider_redirect_page_res
                     # Check for Comcast auto login
                     if 'automatically signing you in' in provider_redirect_page:
-                        oauth_redirect_url = self._html_search_regex(r'window\.location\s*=\s*[\'"]([^\'"]+)',
+                        oauth_redirect_url = self._html_search_regex(
+                            r'window\.location\s*=\s*[\'"]([^\'"]+)',
                             provider_redirect_page, 'oauth redirect')
                         # Just need to process the request. No useful data comes back
-                        self._download_webpage(oauth_redirect_url, video_id, 'Confirming auto login')
+                        self._download_webpage(
+                            oauth_redirect_url, video_id, 'Confirming auto login')
                     else:
                         if '<form name="signin"' in provider_redirect_page:
                             # already have the form, just fill it
                             provider_login_page_res = provider_redirect_page_res
                         elif 'http-equiv="refresh"' in provider_redirect_page:
                             # redirects to the login page
-                            oauth_redirect_url = self._html_search_regex(r'content="0;\s*url=([^\'"]+)',
+                            oauth_redirect_url = self._html_search_regex(
+                                r'content="0;\s*url=([^\'"]+)',
                                 provider_redirect_page, 'meta refresh redirect')
-                            provider_login_page_res = self._download_webpage_handle(oauth_redirect_url,
+                            provider_login_page_res = self._download_webpage_handle(
+                                oauth_redirect_url,
                                 video_id, 'Downloading Provider Login Page')
                         else:
                             provider_login_page_res = post_form(
